%define major	7
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

# based on opencascade 6.9.1
%define occtag	7_8_1
%define version	7.8.1

# tpaviot-oce version 0.18.3
%define ocegit	0.18.3

%define vtkver	9.3

# No openmpi on 32bits with openmpi 5 in Mageia 10+
%ifarch %{ix86} %{arm32}
%bcond_with openmpi
%else
%bcond_without openmpi
%endif

Name:		opencascade
Group:		Sciences/Physics
Version:	%{version}
Release:	%mkrel 5
Summary:	3D modeling & numerical simulation
License:	LGPLv2 with exceptions
URL:		https://github.com/tpaviot/oce
Source0:	https://github.com/Open-Cascade-SAS/OCCT/archive/V%{occtag}/%{name}-%{version}.tar.gz
Patch0:		0001-opencascade-cmake-2.8.1.patch
Patch1:		opencascade-externlib.patch
Patch2:		FixnamingconflictbetweenX11headersandVTK9.2.2.patch
# from gentoo
Patch10:	opencascade-7.7.0-tbb-detection.patch
# Upstream patches
Patch20:	0001-FreeType-Use-unsigned-point-and-contour-indexing.patch
BuildRequires:	pkgconfig(draco)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(xi)
%if %{with openmpi}
BuildRequires:	python3dist(mpi4py)
%endif
BuildRequires:	vtk-devel
BuildRequires:	cmake(rapidjson)
BuildRequires:	cmake(Qt6)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Quick)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Qt6Sql)
Requires:	ksh
Requires:	tcl
Requires:	tix
Requires:	tk

%description
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files
%doc LICENSE_LGPL_21.txt OCCT_LGPL_EXCEPTION.txt
%{_datadir}/%{name}
%{_bindir}/*.sh
%{_bindir}/DRAW*
%{_bindir}/ExpToCasExe*

#-----------------------------------------------------------------------

%package	-n %{libname}
Summary:	3D modeling & numerical simulation
Group:		System/Libraries

%description	-n %{libname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files		-n %{libname}
%{_libdir}/lib*.so.%{major}{,.*}

#-----------------------------------------------------------------------

%package	-n %{devname}
Summary:	3D modeling & numerical simulation
Group:		Development/Other
Requires:	%{libname} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}
Provides:	oce-devel = %{EVRD}

%description	-n %{devname}
Open CASCADE Technology is software development platform freely available
in open source. It includes components for 3D surface and solid modeling,
visualization, data exchange and rapid application development.

Open CASCADE Technology can be best applied in development of numerical
simulation software including CAD/CAM/CAE, AEC and GIS, as well as PDM
applications.

The Technology exists from the mid 1990-s and has already been used by
numerous commercial clients belonging to different domains from software
edition to heavy industry.

%files		-n %{devname}
%{_libdir}/lib*.so
%{_includedir}/%{name}/
%{_libdir}/cmake/opencascade/

#-----------------------------------------------------------------------

%prep
%setup -qn OCCT-%{occtag}

%patch 0 -p1
%if %{with openmpi}
%patch 1 -p1
%endif
#patch 2 -p1
%patch 10 -p1

%patch 20 -p1

# Sources are marked executable for no good reason...
find ./src -type f -exec chmod -x {} \;

# Fix executable set on text files.
chmod 0644 *.txt

#-----------------------------------------------------------------------

%build
# opencascade does some manual install trickery that does not respect DESTDIR.
# Make DESTDIR and environment variable that can be passed into the CMake config.
# export DESTDIR="%%{buildroot}"

%cmake \
       -DCAN_USE_TBB=True -DUSE_TBB=True \
       -D3RDPARTY_TBB_DIR=%{_prefix} \
       -DINSTALL_DIR_LIB=%{_lib} \
       -DINSTALL_DIR_CMAKE=%{_lib}/cmake/%{name} \
       -DUSE_RAPIDJSON=ON \
       -DCAN_USE_DRACO=False -DUSE_DRACO=False \
       -D3RDPARTY_DRACO_LIBRARY=libdraco.so \
       -D3RDPARTY_DRACO_INCLUDE_DIR=%{_includedir}/draco \
       -DCAN_USE_VTK=True -DUSE_VTK=True \
       -D3RDPARTY_VTK_INCLUDE_DIR=%{_includedir}/vtk-%{vtkver}
%cmake_build


#-----------------------------------------------------------------------

%install
%cmake_install

# adjust environment/directories to avoid (too much) script patching
ln -sf %{_libdir} %{buildroot}%{_datadir}/%{name}/lib
ln -sf %{_includedir}/%{name} %{buildroot}%{_datadir}/%{name}/inc
ln -sf %{_datadir}/%{name} %{buildroot}%{_datadir}/%{name}/lin
ln -sf %{_datadir}/%{name} %{buildroot}%{_datadir}/%{name}/Linux


%changelog
* Sun Dec 22 2024 daviddavid <daviddavid> 7.8.1-5.mga10
+ Revision: 2128699
- rebuild for new tbb 2022.0.0

* Fri Nov 22 2024 daviddavid <daviddavid> 7.8.1-4.mga10
+ Revision: 2118628
- replace retired pdksh for ksh

* Tue Aug 27 2024 daviddavid <daviddavid> 7.8.1-3.mga10
+ Revision: 2091768
- add upstream patch to fix build with latest freetype
- rebuild for new tbb 2021.13

* Sun May 12 2024 daviddavid <daviddavid> 7.8.1-2.mga10
+ Revision: 2063832
- re-enable tbb support
+ papoteur <papoteur>
- remove workaround about Destdir

* Sat May 11 2024 papoteur <papoteur> 7.8.1-1.mga10
+ Revision: 2063589
- new version 7.8.1
- disable TBB as said obsolete
- disable draco as not compiling at linking step for now

* Thu May 09 2024 wally <wally> 7.6.3-5.mga10
+ Revision: 2063200
- rebuild for vtk 9.3.0

* Fri Mar 15 2024 daviddavid <daviddavid> 7.6.3-4.mga10
+ Revision: 2049959
- disable openmpi support on 32bits
- rebuild for new draco 1.5.7

* Sun Jan 28 2024 daviddavid <daviddavid> 7.6.3-3.mga10
+ Revision: 2035704
- backport openmandriva patch to add oneTBB 2021 support
- rebuild for tbb 2021.11.0

* Mon Nov 06 2023 daviddavid <daviddavid> 7.6.3-2.mga10
+ Revision: 2004863
- enable draco support
- use system rapidjson

* Thu Nov 03 2022 kekepower <kekepower> 7.6.3-1.mga9
+ Revision: 1902020
- Update Source0 source tarball
- Re-enable upstream patch to fix build with vtk 9.2.2+
- Update to version 7.6.3
- Add upstream patch to fix build with vtk 9.2.2+
- Rebuild for vtk 9.2.2

* Wed Apr 06 2022 umeabot <umeabot> 7.5.0-3.mga9
+ Revision: 1845977
- Mageia 9 Mass Rebuild

* Tue Dec 21 2021 wally <wally> 7.5.0-2.mga9
+ Revision: 1763232
- try to build without vtkFiltersParallelDIY2
- rebuild for vtk 9.1

* Sat Mar 27 2021 daviddavid <daviddavid> 7.5.0-1.mga9
+ Revision: 1711060
- new version: 7.5.0
- move the cmake header files in the devel sub-pkg

* Tue Dec 29 2020 wally <wally> 7.4.0p1-5.mga8
+ Revision: 1664994
- rebuild for missing signature on aarch64

* Thu Dec 17 2020 umeabot <umeabot> 7.4.0p1-4.mga8
+ Revision: 1659210
- Rebuild for new Qt5

* Tue Nov 03 2020 akien <akien> 7.4.0p1-3.mga8
+ Revision: 1642001
- Rebuild for new vtk

* Sun Nov 01 2020 joequant <joequant> 7.4.0p1-2.mga8
+ Revision: 1641065
- add qt5sql
- add cmake files
- add qt5 deps
- add vtk dep
- fix externlib

* Sat Oct 31 2020 joequant <joequant> 7.4.0p1-1.mga8
+ Revision: 1640991
- update xi
- remove vtk
- add tbb
- update to 7.4.0p1

* Sat Oct 31 2020 joequant <joequant> 6.9.1.0.18.3-5.mga8
+ Revision: 1640946
- fix build
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Jan 24 2019 zezinho <zezinho> 6.9.1.0.18.3-3.mga7
+ Revision: 1360487
- fix by arusekk : change cmake path to enable detection

* Sun Sep 23 2018 umeabot <umeabot> 6.9.1.0.18.3-2.mga7
+ Revision: 1299980
- Mageia 7 Mass Rebuild

* Fri Apr 13 2018 kekepower <kekepower> 6.9.1.0.18.3-1.mga7
+ Revision: 1218359
- Update to release 0.18.3

* Thu Jan 11 2018 wally <wally> 6.9.1.0.18.2-2.mga7
+ Revision: 1192381
- provide oce-devel in devel pkg

* Tue Jan 09 2018 wally <wally> 6.9.1.0.18.2-1.mga7
+ Revision: 1191953
- new lib major 11
- new version 6.9.1 + OCE 0.18.2

* Mon Feb 08 2016 umeabot <umeabot> 6.7.0.0.15-4.mga6
+ Revision: 950118
- Mageia 6 Mass Rebuild

* Wed Oct 22 2014 umeabot <umeabot> 6.7.0.0.15-3.mga5
+ Revision: 792430
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ fwang <fwang>
- declare license

* Mon Feb 17 2014 fwang <fwang> 6.7.0.0.15-1.mga5
+ Revision: 593533
- 6.7.0.0.15
+ dmorgan <dmorgan>
- Fix includes header to fix build
+ philippem <philippem>
- add include Xlib
- fix build with include glxext

* Sat Oct 19 2013 umeabot <umeabot> 6.5.4.0.12-2.mga4
+ Revision: 527588
- Mageia 4 Mass Rebuild

* Mon Jun 10 2013 wally <wally> 6.5.4.0.12-1.mga4
+ Revision: 441411
- new major 6
- new version 6.5.4 + OCE 0.12

* Sun Jun 09 2013 wally <wally> 6.5.1.0.7.0-3.mga4
+ Revision: 441366
- add patch to fix broken include dir in OCEConfig.cmake
- fix lib major

* Fri Mar 29 2013 gregorybravas <gregorybravas> 6.5.1.0.7.0-2.mga3
+ Revision: 406095
- licence modified

* Mon Mar 18 2013 gregorybravas <gregorybravas> 6.5.1.0.7.0-1.mga3
+ Revision: 403795
- first update for mgarepo
- imported package opencascade

